@@ -57,7 +57,6 @@ extern "C" Q_DECL_EXPORT int main(int argc, char **argv)
     aboutdata.addAuthor("Andreas Hartmetz", QObject::tr("Maintainer"), "ahartmetz@gmail.com");
     aboutdata.addAuthor("Michael Jansen", QObject::tr("Maintainer"), "kde@michael-jansen.biz");
 
-    app.setWindowIcon(QIcon::fromTheme(QStringLiteral("kglobalaccel")));
     KAboutData::setApplicationData(aboutdata);
 
     {
@@ -76,9 +75,7 @@ extern "C" Q_DECL_EXPORT int main(int argc, char **argv)
     KDBusService service(KDBusService::Unique);
 
     app.setQuitOnLastWindowClosed( false );
-#if QT_VERSION >= QT_VERSION_CHECK(5, 6, 0)
     QGuiApplication::setFallbackSessionManagementEnabled(false);
-#endif
 
     // Restart on a crash
     KCrash::setFlags(KCrash::AutoRestart);
